==> duiba-channel-center-api-0.0.3-sources.jar: cn/com/duiba/cloud/channel/center/api/remoteservice/RemoteSpuChannelService.java <==
package cn.com.duiba.cloud.channel.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.channel.center.api.dto.sale.SaleDTO;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleCopyParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleDetailParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleSaveParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleShelfParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleSpuInfoUpdateParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleUpdateParam;

/**
 * 商品渠道服务
 *
 * @author zsp (zengshuiping@duiba.com.cn)
 * @date 2022/1/4 15:37
 */
@AdvancedFeignClient
@SuppressWarnings("unused")
public interface RemoteSpuChannelService {

    /**
     * 保存渠道相关信息，是一个事务
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean saveSale(SaleSaveParam param) throws BizException;

    Boolean updateSale(SaleUpdateParam param) throws BizException;


    /**
     * 获取渠道信息
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    SaleDTO getBySpuIdAndAppId(SaleDetailParam param) throws BizException;


    /**
     * 通过spuId来更新Spu信息信息
     *
     * @param updateParam
     *
     * @return
     * @throws BizException
     */
    int updateSpuInfoBySpuId(SaleSpuInfoUpdateParam updateParam) throws BizException;


    /**
     * 商品上下架
     *
     * @param shelfParam
     *
     * @return
     * @throws BizException
     */
    Boolean changeShelfStatus(SaleShelfParam shelfParam) throws BizException;


    /**
     * 选品
     *
     * @return
     * @throws BizException
     */
    Boolean copySale4SameSupplier(SaleCopyParam saleCopyParam) throws BizException;
}

==> duiba-channel-center-api-0.0.6-20220407.020148-6-sources.jar: cn/com/duiba/cloud/channel/center/api/remoteservice/RemoteSpuChannelService.java <==
package cn.com.duiba.cloud.channel.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.channel.center.api.dto.sale.SaleDTO;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleCopyParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleDetailParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleRemoveParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleSaveParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleShelfParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleSpuInfoUpdateParam;
import cn.com.duiba.cloud.channel.center.api.param.sale.SaleUpdateParam;

/**
 * 商品渠道服务
 *
 * @author zsp (zengshuiping@duiba.com.cn)
 * @date 2022/1/4 15:37
 */
@AdvancedFeignClient
@SuppressWarnings("unused")
public interface RemoteSpuChannelService {

    /**
     * 保存渠道相关信息，是一个事务
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean saveSale(SaleSaveParam param) throws BizException;

    Boolean updateSale(SaleUpdateParam param) throws BizException;


    /**
     * 获取渠道信息
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    SaleDTO getBySpuIdAndAppId(SaleDetailParam param) throws BizException;


    /**
     * 通过spuId来更新Spu信息信息
     *
     * @param updateParam
     *
     * @return
     * @throws BizException
     */
    int updateSpuInfoBySpuId(SaleSpuInfoUpdateParam updateParam) throws BizException;


    /**
     * 商品上下架
     *
     * @param shelfParam
     *
     * @return
     * @throws BizException
     */
    Boolean changeShelfStatus(SaleShelfParam shelfParam) throws BizException;


    /**
     * 选品
     *
     * @return
     * @throws BizException
     */
    Boolean copySale4SameSupplier(SaleCopyParam saleCopyParam) throws BizException;


    /**
     * 全量读取 db 写入 es
     */
    void writeEs();


    /**
     * 删除商品
     *
     * @param param
     *
     * @return
     * @throws BizException
     */
    Boolean remove(SaleRemoveParam param) throws BizException;
}
